.LP
.nf
     ELMT05                         FEAP ELEMENT USERS MANUAL
     --------------------------------------------------------
	imat
	amat,itype,ii,rho
	d(i),i=1,n
     --------------------------------------------------------
.PP
ELMT05 is a general plane strain and axisymmetric element for 
several elastic and inelastic and isotropic materials.  
The element includes models defined by imat for:
.nf

	imat = 1: linear isotropic elasticity
	imat = 2: linear isotropic viscoelasticity
	imat = 3: isotropic viscoelasticity with damage
	imat = 4: elastic-viscoplastic model
	imat = 5: elastic-plastic mises with hardening
	imat = 6: elastic plastic drucker/prager (nonassociative)
.PP
The material and property descriptions are included after a 'mate'
in the mesh specification.  For ELMT05, which is a  4-node
element, the parameters to be specified are:
.nf

     amat = 'steel' or 'users' (N.B. steel parameters are in lb,in,sec)
     itype= 0 for plane strain; 1 for axisymmetric analysis.
     ibar = 0 for b-bar method; 1 for conventional b matrix
     rho  = mass density
.PP
The 'b' array is the finite element strain-displacement matrix.  The
notation 'b-bar' refers to a modification to permit nearly incompressible
behavior to be properly modeled (non-locking).  Use of the 'steel' option
permits the user to input a blank record for the d(i) parameters which
will be set by the program to nominal values 
.nf

     d(1) = K  = 25.0e+06      (bulk modulus)
     d(2) = G  = 30.0e+06/2.6  (shear modulus)
     d(3) = Y0 = 30.0e+03      (initial yield stress
     d(4) = YI = 40.0e+03      (saturation yield stess)
     d(5) = B  = 1.5           (saturation parameter)
     d(6) = H  = 0.0           (linear hardening)
     d(7) = b  = 0.5           (percent isotropic hardening)
     d(8) = rho= 7.25e-04      (density)
.PP
These properties are applicable only to the elastic and elastic-plastic
options (isw = 1; or imat = 5) for other options or material types
the user must specify values for the parameters d(i) according to the
following:
.nf

     isw = 1 (linear elasticity)

      d(1) = K (bulk modulus)
      d(2) = G (shear modulus)
      d(3) = Y (yield stress)
.bp
     isw = 2 (linear viscoelasticity)

      d(1) = K  (bulk modulus)
      d(2) = G0 (short term shear modulus)
      d(3) = GI (long term shear modulus)
      d(4) = Bt ( time constant in exponential - exp(Bt*t) )

     isw = 3 (linear viscoelasticity with damage)

      d(1) = K  (bulk modulus)
      d(2) = G0 (short term shear modulus)
      d(3) = GI (long term shear modulus)
      d(4) = Bt ( time constant in exponential - exp(Bt*t) )
      d(5) = damage limit
      d(6) = damage exponent (see SESM Report No. 83/10)

     isw = 4 (elastic viscoplastic)

      d(1) = K  (bulk modulus)
      d(2) = G  (shear modulus)
      d(3) = Y  (yield stress)
      d(4) = R  (yield circle radius - set by program)
      d(5) = gamma - time constant (default = 0.001)
      d(6) = n - power of yield function ratio 

     isw = 5 (elastic plastic with hardening)

      d(1) = K  (bulk modulus)
      d(2) = G  (shear modulus)
      d(3) = Y0 (initial yield stress)
      d(4) = YI (saturation yield stress)
      d(5) = B  (saturation parameter)
      d(6) = H  (linear hardening)
      d(7) = b  (percent isotropic hardening)

     isw = 6 (drucker/prager nonassociative platicity)

      d(1) = K  (bulk modulus)
      d(2) = G  (shear modulus)
      d(3) = Y0 (yield stress)
      d(4) = R  (yield circle radius - set by program)
      d(5) = pressure parameter - tangent(alpha)


.PP
The element requires a two dimensional mesh and uses the first
two coordinate values for x and y, respectively.  Similarly, the
element uses the first 2-dof at each node for the u-x and u-y 
displacement values, respectively.
.PP
ELMT05 requires that the control information be set so that 'ndm'
(space dimension of mesh) is 2 or more (maximum 3); 'ndf' maximum
number of degree-of-freedoms at a node are 2 or more (maximum 6);
and 'nen' (maximum number of nodes attached to an element) be 4 or more.
.bp
.PP
Stresses and strains are reported at the element center as follows:
.nf
     11-stress  - normal stress in 1-coordinate direction
     12-stress  - shearing stress in 12-plane
     22-stress  - normal stress in 2-coordinate direction
     33-stress  - normal stress in 3-coordinate direction
      1-stress  - major principal stress in 12-plane
      2-stress  - minor principal stress in 12-plane
     yield ratio- ratio of yield stress to initial yield stress
      angle     - angle 1-stress makes with 1-coordinate
	          direction (in degrees).
.PP
These stresses may be projected to nodes using either the 'stre,node'
macro or during plotting by the 'plot,stre' operation.
.LP
This element is non-linear in its material behavior for all isw
greater than 2; accordingly, nonlinear solution options must be
employed to obtain reliable computational results.  For plasticity
analyses it has proved necessary to employ a line search (i.e.,
use a 'solv,line' macro) to obtain convergence with moderate to
large load steps.
.bp
